@@ -12,12 +12,12 @@ class ChromiePathFinder(dict):
 
     @property
     def root(self):
-        return os.path.join(self.path, self.name)
+        return os.path.abspath(os.path.join(self.path, self.name))
 
     def __call__(self, dir):
         if not dir:
             raise ValueError(f"No path with the name {name} exists")
-        return os.path.abspath(os.path.join(self.root, dir))
+        return os.path.join(self.root, dir)
 
     def exists(self, name=""):
         path = os.path.abspath(os.path.join(self.root, name))
